Module check

Module check 

Structs

CheckOptions
Options for the oseda check command

Enums

OsedaCheckError
All common error types that could cause oseda check to fail
OsedaProjectStatus
Status of Oseda project, plan to make this more verbose later

Functions

check
Checks the Oseda project in the working directory for common oseda errors