check

Function check 

pub fn check(opts: CheckOptions) -> Result<(), OsedaCheckError>
Checks the Oseda project in the working directory for common oseda errors

Arguments

  • opts - options parsed from CLI flags

Returns

  • Ok(()) if the project passes all checks and is considered as “deployabl“e
  • Err(OsedaCheckError) a problem was detected that prevents the user from doing a deployment