Function deploy
Source pub fn deploy(opts: DeployOptions) -> Result<(), Box<dyn Error>>
Deploys an Oseda project to the provided fork URL
Arguments
opts - options with the fork_url for the deployment target
Returns
Ok(()) on success
Err if any git, file, or config step fails, including a check failsure