Module config

Module config 

Structs

OsedaConfig
Structure for an oseda-config.json

Functions

create_conf
Prompts the user for everything needed to generate a new OsedaConfig
prompt_for_title
read_and_validate_config
Reads and validates an oseda-config.json file in the working directory
read_config_file
update_time
Updates the configs last-updated Currently this is used on creation only, TODO fix this
validate_config
write_config
Write an OsedaConfig to the provided directory