pub enum Commands {
Init(InitOptions),
Run,
Check(CheckOptions),
Deploy(DeployOptions),
Fork,
}Expand description
Oseda subcommand, represents an action to take on your Oseda project
Variants
Init(InitOptions)
Initialize a new Oseda project in the working directory
Run
Run the Oseda project in the working directory
Check(CheckOptions)
Check the Oseda project in the working directory for common errors
Deploy(DeployOptions)
Deploy your Oseda project to github to add to oseda.net
Fork
Fork the library repository to submit your course