Function git
Source pub fn git(dir: &Path, args: &[&str]) -> Result<(), Box<dyn Error>>
Super generic run git func for general usecases git commands
Arguments
dir - the directory to run the git command in
args - the list of arguments to pass to git -> e.g. ["clone", "[URL]" ]
Returns (based on git exit code)
Ok(()) if the git command succeeds
Err if the command fails