Module puppeteer

Module puppeteer 

Functions

is_puppeteer_chrome_installed
Checks whether headless Chrome has been installed on the users system via npx puppeteer
prompt_install_puppeteer_chrome
Prompts the user for an installation of headless Chrome via. Puppeteer, installing it if they elect to proceed