Structs
- Check
Options - Options for the
oseda checkcommand
Enums
- Oseda
Check Error - All common error types that could cause
oseda checkto fail - Oseda
Project Status - Status of Oseda project, plan to make this more verbose later
Functions
- check
- Checks the Oseda project in the working directory for common oseda errors