pub fn run() -> Result<(), OsedaRunError>Expand description
Runs an Oseda project in the working directory
This will:
- Run
npx vite build - Start a static file server (
serve dist) - Gracefully listen for Ctrl+C to shut down the server
- This gracefull-ness here is important, this runs on a separate thread, do not attempt to orphan this process
Returns
Ok(())if both the build and serve steps succeedErr(OsedaRunError)if any step fails (missing vite isn’t installed, orservefails to start)