Structs
- Oseda
Config - Structure for an oseda-config.json
Functions
- create_
conf - Prompts the user for everything needed to generate a new OsedaConfig
- read_
and_ validate_ config - Reads and validates an oseda-config.json file in the working directory
- read_
config_ file - update_
time - Updates the configs last-updated Currently this is used on creation only, TODO fix this
- validate_
config - write_
config - Write an OsedaConfig to the provided directory