Module config

Structs

OsedaConfig
Structure for an oseda-config.json

Functions

create_conf
Prompts the user for everything needed to generate a new OsedaConfig
read_and_validate_config
Reads and validates an oseda-config.json file in the working directory
update_time
Updates the configs last-updated Currently this is used on creation only, TODO fix this
write_config
Write an OsedaConfig to the provided directory